#
# spec file for package xfce4-notes-plugin
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define panel_version 4.12.0
%define plugin notes
%bcond_with git
Name:           xfce4-%{plugin}-plugin
Version:        1.11.0
Release:        2.3
Summary:        Note-taking Plugin for the Xfce Panel
License:        GPL-2.0-or-later
Group:          System/GUI/XFCE
URL:            https://docs.xfce.org/panel-plugins/xfce4-notes-plugin
Source0:        https://archive.xfce.org/src/panel-plugins/%{name}/1.10/%{name}-%{version}.tar.bz2
BuildRequires:  fdupes
%if 0%{?suse_version} >= 1699
BuildRequires:  gcc13
%endif
BuildRequires:  intltool
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(gio-2.0) >= 2.30.0
BuildRequires:  pkgconfig(glib-2.0) >= 2.30.0
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.22.0
BuildRequires:  pkgconfig(libxfce4panel-2.0) >= 4.14.0
BuildRequires:  pkgconfig(libxfce4ui-2) >= 4.14.0
BuildRequires:  pkgconfig(libxfce4util-1.0) >= 4.14.0
BuildRequires:  pkgconfig(libxfconf-0) >= 4.14.0
%if %{with git}
BuildRequires:  xfce4-dev-tools
BuildRequires:  pkgconfig(xfce4-vala)
%endif
# uses exo-open
Requires:       exo-tools
Requires:       xfce4-panel >= %{panel_version}
Recommends:     %{name}-lang = %{version}
# package was renamed in 2019 after Leap 15.1
Provides:       xfce4-panel-plugin-%{plugin} = %{version}-%{release}
Obsoletes:      xfce4-panel-plugin-%{plugin} < %{version}-%{release}
Obsoletes:      xfce4-panel-plugin-%{plugin}-debuginfo

%description
The Notes plugin provides the equivalent to post-it notes on the Xfce desktop
and allows to quickly take and store small notes.

%package lang
Summary:        Translations for package %{name}
Group:          System/Localization
Requires:       %{name} = %{version}
Supplements:    %{name}
Provides:       %{name}-lang-all = %{version}
# package was renamed in 2019 after Leap 15.1
Obsoletes:      xfce4-panel-plugin-%{plugin}-lang < %{version}-%{release}
Provides:       xfce4-panel-plugin-%{plugin}-lang = %{version}-%{release}
BuildArch:      noarch

%description lang
Provides translations for the "%{name}" package.

%prep
%autosetup

%build
%if 0%{?suse_version} >= 1699
export CC=gcc-13
%endif
%if %{with git}
NOCONFIGURE=1 ./autogen.sh
%configure \
  --enable-maintainer-mode \
  --disable-static
%else
%configure --disable-static
%endif
%make_build

%install
%make_install

rm %{buildroot}%{_libdir}/xfce4/panel/plugins/libnotes.la

%suse_update_desktop_file xfce4-notes
%suse_update_desktop_file xfce4-notes-autostart

%find_lang %{name} %{name}.lang %{?no_lang_C}

%fdupes %{buildroot}%{_datadir}

%files
%doc AUTHORS NEWS README.md
%license COPYING
%{_bindir}/xfce4-notes
%{_bindir}/xfce4-notes-settings
%{_bindir}/xfce4-popup-notes
%{_datadir}/xfce4/notes
%{_datadir}/icons/hicolor/*/apps/*xfce.notes.*
%{_datadir}/icons/hicolor/*/apps/*xfce.panel.notes.*
%{_datadir}/xfce4/panel/plugins/xfce4-notes-plugin.desktop
%{_datadir}/applications/xfce4-notes.desktop
%{_libdir}/xfce4/panel/plugins/libnotes.so
%{_sysconfdir}/xdg/autostart/xfce4-notes-autostart.desktop

%files lang -f %{name}.lang

%changelog
* Fri Aug 30 2024 Manfred Hollstein <manfred.h@gmx.net>
- Vala does not properly work with gcc-14; lets stick with gcc-13
  for now on Tumbleweed/Slowroll.
* Sun Jan 14 2024 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 1.11.0
  * Update copyright year
  * Make default notes names in singular form
  * Start numbering the notes with 1
  * Rework Xnp.Window.insert_note()
  * Use separate icon for logo
  * Make menu icon themed
  * Notes path change: handle case when both apps are running
  * Rework Xnp.Application.update_notes_path()
  * Don't ask when deleting a group with one blank note
  * Fix notebook tab prelight
  * Focus previous notes window when hiding a window
  * Rework Xnp.Application.show_hide_notes()
  * Avoid focus loss when removing a group
  * Avoid focus loss for note windows
  * Store "skip-taskbar-hint" property in Xnp.Application
  * Rewrite links processing code
  * Switch to previous page after deleting current note
  * Merge delete_note with delete_current_note
  * Use separate icon names for panel, tray and application
  * Switch to rDNS icon naming scheme
  * Fix segfault when pressing Ctrl+W on empty group
  * Use default values for externally created groups
  * Rework notes window switching processing
  * Handle empty group window titles
  * Add notes path setting
  * Slightly change the design of settings dialog
  * Fix Xfconf "notes-path" property handling
  * Fix background color of title bar when renaming a group
  * Reduce frequency of saving windows configuration
  * Undo/redo: make cursor position behavior natural
  * Fix the logic of "move-cursor" signal detection
  * Remember windows focus order
  * Rework access to Xnp.Application.window_list from Xnp.Window
  * Escape window title for markup parser
  * Save windows configuration before group reloading
  * Make transition to new version seemless
  * Update tags immediately after loading a note
  * Slightly improve undo/redo processing
  * Simplify code
  * Allow note tabs to be moved between groups
  * New method: Xnp.Window.get_tab_evbox()
  * New method: Xnp.Window.get_note()
  * New property: Xnp.Window.current_note
  * Rework Xnp.Window.n_pages
  * Save windows configuration when in system tray mode
  * Rework application termination sequence
  * Simplify save_windows_configuration()
  * Prevent possible data loss when saving notes
  * Fix mouse cursor behavior after clicking on a link
  * Refuse to create/delete notes on file system errors
  * Handle errors when renaming a note
  * Report errors when creating/deleting notes
  * Select note before deletion request
  * Delete note with middle mouse click on tab
  * Handle errors when creating a group
  * Handle errors when deleting a group
  * Handle errors when renaming a group
  * Add error popup if note could not be saved
  * Save notes only when changed
  * Overwrite windows configuration only when changed
  * Save current note on page switching or focus loss
  * Don't overwrite notes on program start up
  * Add titles to dialog windows
  * Make title text color independent of gtk theme
  * Make title bar arrows respond to mouse scroll events
  * Replace mouse button numbers with constants
  * Set default icon name for application
  * Use pure gtk style when selecting "GTK+" color
  * Separate color css to a separate Gtk.CssProvider
  * Make titlebar customized
  * Simplify access to notebook pages
  * Rename note with double click on tab
  * Cleanup
  * Add icons to dialog windows
  * Fix notebook tab names for new notes
  * Don't change the title label sensitivity
  * Add a note about possibility of css customization
  * Allow resizing notes window from the top border
  * Change accelerators hexa values to symbolic names
  * Reset timeout_background when timer reaches end
  * Make 'GTK+' background color work
  * Bring back the choice of background color
  * Add support for ~/.config/gtk-3.0/gtk.css
  * Fix background color of disabled arrow
  * Get rid of ~/.config/xfce4/notes/xfce4-notes.css
  * Rename gtk-main.css -> gtk.css
  * Add support for system wide css customizations
  * Unite update_css() and update_style_context()
  * Move data files to $(datadir)/xfce4/notes
  * Derive hypertext link color from theme
  * Redraw main menu icon on mouse enter/leave events
  * Allow user to customize main menu icon
  * Add support for custom css
  * Replace 'Remove' with 'Quit' in application menu
  * Don't overwrite xfce4-notes.css without a need
  * Reload css instead of adding it over and over again
  * Move resource files to xfce4/notes subdirectory
  * Auto create config directory
  * Replace Gdk.Color with Gdk.RGBA
  * Don't use stock gtk elements to create menu
  * Simplify menu creation
  * Gtk.Image.from_stock() -> Gtk.Image.from_icon_name()
  * Bring menu icons back
  * Change authors order
  * Translation Updates
* Sun Mar 19 2023 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 1.10.0
  * Add copyright notice to configure.ac
  * Change maintainer
  * Minor fixes to README
  * Fix compilation warnings
  * Fix double g_object_unref() on removing last note
  * Fix double call to gtk_main_quit()
  * Change default background color
  * build: Silence compiler warnings for generated C code
  * Update `.gitignore`
  * Switch tabs on mouse wheel with no accelerators pressed
  * Add ability to switch tabs with mouse scroll wheel
  * Unmask scroll wheel events for window title
  * Fix background color for panel plugin button
  * Fix up intltool leaving .intltool-merge-cache.lock file behind
  * Update COPYING
  * Make note text darker and easier to see
  * Translation Updates
- Remove _service file
* Sat Nov 20 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Drop unused pkgconfig(unique-1.0) BuildRequires.
* Tue Jan 19 2021 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 1.9.0
- Remove unused variable
  - Update deprecated autotools macros
  - Do not mark text with ':' after '://' as a link
    (gxo#panel-plugins/xfce4-notes-plugin#52)
  - Add support for links with scheme other than HTTP
    (gxo#panel-plugins/xfce4-notes-plugin#52)
  - Fix missing-prototypes
  - Create README.md. Update configure.ac.in
  - Add basic gitlab CI
  - Fix "Disabled labels on context menu are dark yellow"
  - Fix a few deprecation warnings
  - Fix make distcheck
  - Fix blinking image on panel
  - Remove commented code
  - Update build system
  - Fix make distcheck
  - Remove deprecated gtk stock usage
  - Fix build system
  - Continue the gtk3 port
  - Update URLs from goodies.x.o to docs.x.o (bxo#16171)
  - po: update POTFILES.in
  - gtk3: update css style with required changes from 3.20
  - gtk3: drop libunique leftover flags and code
  - gtk3: Drop support for GTK+-2.0
  - bump post release
  - Translation Updates
* Thu Jan  7 2021 Maurizio Galli <maurizio.galli@gmail.com>
- Fixed dependency requirements to GTK3
* Fri Aug 16 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Fixed sources in spec file
* Wed Jul 17 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Package renamed to follow upstream name xfce4-foo-plugin
- Use lang subpackage for manual edits instead of %%lang_package macro
- Cleaned up spec file
- Added bcond for git master builds
- Use %%license macro for COPYING
* Mon Jun 29 2015 gber@opensuse.org
- update to version 1.8.1
  - provide graphics tabs/ for gtk-2.0 theme
  - fit panel button inside a single panel row (for deskbar mode)
* Sun Apr 19 2015 gber@opensuse.org
- update to version 1.8.0
  - Dependencies: match Xfce 4.10 requirements
  - Vala: Compilation fixes, and fixed build for GTK2 and GTK3 to
    work together.
  - GTK3: Added support for GTK3 and theming through GtkCssProvider,
    it's still missing features from GTK2 code, and doesn't build
    a panel plugin. Build with --enable-gtk3 from Git (dist do not
    permit to rebuild from Vala.)
  - Settings: New hidden notes-path setting tweakable through
    xfconf.
  - Monitor: Add monitoring of notes files to allow hot-edition and
    refresh in notes windows.
  - Other misc fixes.
  - Updated translations
- drop obsolete
  xfce4-panel-plugin-notes-create-unversioned-lib.patch and
  xfce4-panel-plugin-notes-automake-1.13.patch
* Wed Mar 13 2013 pgajdos@suse.cz
- builds with automake 1.13
  * automake-1.13.patch
* Sat Aug 18 2012 gber@opensuse.org
- correct the name of the desktop file in order to prevent
  migration issues (bxo#6993)
* Sun Apr 29 2012 gber@opensuse.org
- add dependency on exo-tools since exo-open is used
* Fri Apr 20 2012 gber@opensuse.org
- added documentation files
- added xfce4-panel-plugin-notes-create-unversioned-lib.patch in
  order to build the plugin module as an unversioned lib, also
  install it in the default panel plugin module path
- removed xfce4-panel-plugin-notes-1.7.7-fix-desktop-file.patch
  which is obsoleted by the above
* Tue Apr 17 2012 gber@opensuse.org
- corrected source URL
* Tue Apr  3 2012 gber@opensuse.org
- dropped unnecessary
  xfce4-panel-plugin-notes-1.7.7-add-missing-vapi-files.patch
- specfile cleanup
- correct dependencies
- split off -lang subpackage
* Wed Jul 27 2011 gber@opensuse.org
- removed unnecessary dependency on vala
* Wed Mar  9 2011 gber@opensuse.org
- new package (split off from xfce4-panel-plugins)
